==> zio-aws-globalaccelerator_2.13-5.17.161.1-sources.jar: zio/aws/globalaccelerator/model/CreateCustomRoutingListenerResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateCustomRoutingListenerResponse(
    listener: Option[zio.aws.globalaccelerator.model.CustomRoutingListener] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse = {
    import CreateCustomRoutingListenerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
      .builder()
      .optionallyWith(listener.map(value => value.buildAwsValue()))(_.listener)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse
      .wrap(buildAwsValue())
}
object CreateCustomRoutingListenerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse =
      zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse(
        listener.map(value => value.asEditable)
      )
    def listener
        : Option[zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly]
    def getListener: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly
    ] = AwsError.unwrapOptionField("listener", listener)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ) extends zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly {
    override val listener: Option[
      zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly
    ] = scala
      .Option(impl.listener())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingListener.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ): zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.20.22.2-sources.jar: zio/aws/globalaccelerator/model/CreateCustomRoutingListenerResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateCustomRoutingListenerResponse(
    listener: Optional[zio.aws.globalaccelerator.model.CustomRoutingListener] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse = {
    import CreateCustomRoutingListenerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
      .builder()
      .optionallyWith(listener.map(value => value.buildAwsValue()))(_.listener)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse
      .wrap(buildAwsValue())
}
object CreateCustomRoutingListenerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse =
      zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse(
        listener.map(value => value.asEditable)
      )
    def listener: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly
    ]
    def getListener: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly
    ] = AwsError.unwrapOptionField("listener", listener)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ) extends zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly {
    override val listener: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingListener.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.listener())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingListener.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateCustomRoutingListenerResponse
  ): zio.aws.globalaccelerator.model.CreateCustomRoutingListenerResponse.ReadOnly =
    new Wrapper(impl)
}
